(define-package
  "solarized-theme"
  "1.2.2"
  "The Solarized color theme, ported to Emacs."
  '((emacs "24.1") (cl-lib "0.5") (dash "2.6.0")))
